@@ -1,6 +1,6 @@
 package App::PPI::Dumper;
 
-our $VERSION = "1.022";
+our $VERSION = "1.023";
 
 =encoding utf8
 
@@ -75,7 +75,7 @@ comes directly from PPI::Dumper. I just made a command-line tool for it.
 
 This code is in Github:
 
-	git://github.com/briandfoy/app-ppi-dumper.git
+	https://github.com/briandfoy/app-ppi-dumper.git
 
 =head1 AUTHOR
 
@@ -83,7 +83,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright © 2009-2021, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2009-2022, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 You may redistribute this under the terms of the Artistic License 2.0.
 
